winio-webview2 0.1.0

WebView2 Win32 bindings for Rust
docs.rs failed to build winio-webview2-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: winio-webview2-0.2.2